summaryrefslogtreecommitdiffstats
path: root/src/titlefactor.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/titlefactor.cpp')
-rw-r--r--src/titlefactor.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/titlefactor.cpp b/src/titlefactor.cpp
index 0d48c28..774551e 100644
--- a/src/titlefactor.cpp
+++ b/src/titlefactor.cpp
@@ -243,11 +243,11 @@ static const unsigned char img0_titlefactor[] = {
/*
* Constructs a titleFactor as a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'.
*/
-titleFactor::titleFactor( TQWidget* tqparent, const char* name, WFlags fl )
- : TQWidget( tqparent, name, fl )
+titleFactor::titleFactor( TQWidget* parent, const char* name, WFlags fl )
+ : TQWidget( parent, name, fl )
{
TQImage img;
img.loadFromData( img0_titlefactor, sizeof( img0_titlefactor ), "PNG" );
@@ -243,11 +243,11 @@ static const unsigned char img0_titlefactor[] = {
/*
- * Constructs a titleFactor as a child of 'tqparent', with the
+ * Constructs a titleFactor as a child of 'parent', with the
* name 'name' and widget flags set to 'f'.
*/